# AUC

[Назад к списку компонентов](../README.md)

## Назначение

Предназначен для расчета индекса AUC, стандартной ошибки, доверительных интервалов, Z-оценки для оценки качества модели.

Присутствует словесная ценка качества модели. Результаты выводятся в переменных.

## Входные порты

| Название                         | Тип        |
|:---------------------------------|:-----------|
| Фактические и оцененные значения | Таблица    |
| Параметры алгоритма              | Переменные |

### Структура таблицы "Фактические и оцененные значения"

| Метка   | Тип                                    | Описание                                                                          |
|:--------|:---------------------------------------|:----------------------------------------------------------------------------------|
| Событие | ![](./img/logical.svg) Логический      | **true** соответствует событию, **false** — не-событию                            |
| Оценка  | ![](./img/realnumber.svg) Вещественный | Оценка, которую выдал алгоритм (вероятность, балл, рейтинг, достоверность и т.д.) |

### Переменные в порте "Параметры алгоритма"

| № | Метка    | Тип                          | Значение   |
|:--|:---------|:-----------------------------|:-----------|
| 1 | Точность | ![](./img/integer.svg) Целый | 4          |

**Точность** — точность вычисления выходных значений (знаков после запятой). Влияет на скорость расчетов: чем выше точность, тем дольше вычисления.

## Выходные порты

| Название   | Тип        |
|:-----------|:-----------|
| Результаты | Переменные |

### Переменные в порте "Результаты"

| № | Метка                          | Тип                                    | Описание                                               |
|:--|:-------------------------------|:---------------------------------------|:-------------------------------------------------------|
| 1 | Индекс AUC                     | ![](./img/realnumber.svg) Вещественный | Расчитанное значение индекса AUC для модели            |
| 2 | Качество                       | ![](./img/string.svg) Строковый        | Словесное описание качества модели (см. **Алгоритмы**) |
| 3 | Стандартная ошибка             | ![](./img/realnumber.svg) Вещественный | Стандартное отклонение по набору                       |
| 4 | Доверительный интервал нижний  | ![](./img/realnumber.svg) Вещественный | Нижняя граница доверительного интервала                |
| 5 | Доверительный интервал верхний | ![](./img/realnumber.svg) Вещественный | Верхняя граница доверительного интервала               |
| 6 | Z-оценка                       | ![](./img/realnumber.svg) Вещественный | Расчитанное значение Z-оценки                          |

## Алгоритмы

### Индекс AUC

Используется стандартный алгоритм расчета площади под кривой. Кумулятивные доли событий и не-событий рассчитываются для каждого изменения выходной переменной **Оценка**, предварительно округленной до (**Accuracy + 1**) знаков после запятой.

### Качество

Текстовое поле формируется на основе следующих правил.

|  Интервал AUC | Качество модели      |
|:--------------|:---------------------|
|         > 0,9 | Отличное             |
| [ 0,8 - 0,9 ] | Очень хорошее        |
| ( 0,7 - 0,8 ] | Хорошее              |
| ( 0,6 - 0,7 ] | Среднее              |
|        <= 0,6 | Неудовлетворительное |

### Стандартное отклонение

Рассчитывается методом [**Hanley & McNeil, 1982**]<sup><a href="#1">1</a></sup>.

Расчеты имеют вид:

![Q_{1}= \frac{AUC}{2-AUC}](./img/1_auc.svg)

![Q_{2}= \frac{2AUC^{2} }{1+AUC}](./img/2_auc.svg)

![SE= \sqrt{ \frac{AUC(1-AUC)+(na-1)( Q_{1}- AUC^{2})+(nn-1)( Q_{2}- AUC^{2})}{na \cdot nn} }](./img/3_auc.svg)

### Доверительный интервал

Границы доверительного интервала для AUC рассчитываются следующим образом:

![CI=AUC \pm 1,96SE](./img/4_auc.svg)

### Z-оценка

Расчеты имеют вид:

![Z= \frac{AUC-0,5}{SE}](./img/5_auc.svg)

Критическое значение z-оценки для уровня значимости 95% принимается равным 1,96. Если *|z|* > 1,96, то гипотеза о случайности оценки площади под кривой (*AUC* = 0,5) отвергается.

## Дополнительная литература

1. <a id="1"/>[The meaning and use of the area under a receiver operating characteristic (ROC) curve](https://www.ncbi.nlm.nih.gov/pubmed/7063747)

2. [The magnificent ROC(Receiver Operating Characteristic curve)](http://www.anaesthetist.com/mnm/stats/roc/Findex.htm)

3. [Details of calculations for ROC curves](https://graphpad.com/support/faq/details-of-calculations-for-roc-curves/)
