# Динамика события

[Назад к списку компонентов](../README.md)

## Назначение

Вычисление накопительной доли событий по когортам, общей доли событий, определение точки стабилизации. Когорты формируются на основе периода регистрации. 

Для компонента настроены отчеты:

* Доля событий по когортам;
* Доля событий.

## Входные порты

| Название              | Тип        |
|:----------------------|:-----------|
| Входной набор данных  | Таблица    |
| Переменные            | Переменные |

### Структура таблицы "Входной набор данных"

| Метка                   | Тип                                  | Описание                                                                                                 |
|:------------------------|:-------------------------------------|:---------------------------------------------------------------------------------------------------------|
| Идентификатор объекта   | ![](./img/string.svg) Строковый      | Уникальный идентификатор объекта (например, код клиента)                                                 |
| Дата регистрации        | ![](./img/datetime.svg) Дата/Время   | Дата появления объекта (например, заключения договора с клиентом)                                        |
| Дата первого события    | ![](./img/datetime.svg) Дата/Время   | Дата первого события с объектом (например, дата первой покупки). Может совпадать с **датой регистрации** |
| Дата второго события    | ![](./img/datetime.svg) Дата/Время   | Дата второго события с объектом (например, дата второй покупки)                                          |

### Переменные в порте "Переменные"

| № | Метка          | Тип                                        | Значение |
|:--|:---------------|:-------------------------------------------|:---------|
| 1 | Тип когорты    | ![](./img/string.svg) Строковый            | m        |
| 2 | Тип периода    | ![](./img/string.svg) Строковый            | m        |
| 3 | Порог, %       | ![](./img/realnumber.svg) Вещественный     | 80       |

1. **Тип когорты**/**периода** — определяет величину периода для формирования когорт и расчета периодов жизни когорты:

* **d** — день;
* **w** — неделя;
* **m** — месяц (по умолчанию);
* **q** — квартал.

2. **Порог, %** — граница порога, % объектов, при котором мы считаем, что событие произошло для большинства.

## Выходные порты

| Название                  | Тип        |
|:--------------------------|:-----------|
| Доля событий по когортам  | Таблица    |
| Доля событий              | Таблица    |
| Точка стабилизации        | Переменные |

### Структура таблицы "Доля событий по когортам"

| Метка                   | Тип                                       | Описание                                                                            |
|:------------------------|:------------------------------------------|:------------------------------------------------------------------------------------|
| Когорта                 | ![](./img/datetime.svg) Дата/Время        | Название когорты (первая дата периода, к которому относится **Дата регистрации**)   |
| Период                  | ![](./img/integer.svg) Целый              | Порядковый номер периода                                                            |
| Количество объектов     | ![](./img/integer.svg) Целый              | Количество объектов по каждой когорте, для которых событие произошло в текущем периоде   |
| % объектов накопительно | ![](./img/realnumber.svg) Вещественный    | % объектов по каждой когорте, для которых событие произошло к концу текущего периода     |

### Структура таблицы "Доля событий"

| Метка                   | Тип                                    | Описание |
|:------------------------|:---------------------------------------|:---------|
| Период                  | ![](./img/integer.svg) Целый           | Порядковый номер периода |
| % объектов накопительно | ![](./img/realnumber.svg) Вещественный | % объектов по всем когортам, для которых событие произошло к текущему периоду   |

### Переменные в порте "Точка стабилизации"

| № | Метка                 | Тип                            | Описание                                                                                        |
|:--|:----------------------|:-------------------------------|:------------------------------------------------------------------------------------------------|
| 1 | Точка стабилизации    | ![](./img/integer.svg) Целый   | Номер периода, в котором был достигнут заданный процент объектов, с которыми событие произошло  |

## Алгоритмы

1. Определение периода для каждой даты и выделение когорт.
2. Расчет количества периодов между датой первого и второго событий.
3. Подсчет количества объектов, для которых событие произошло в определенный номер периода.
4. Подсчет накопительного процента объектов, для которых событие произошло к концу текущего периода.
