# Статистическая значимость

[Назад к списку компонентов](../README.md)

## Назначение

Компонент для проверки статистической значимости с помощью одностороннего T-теста, двустороннего T-теста, теста Манна-Уитни (U-тест) на выбор.

## Входные порты

| Название             | Тип        |
|:---------------------|:-----------|
| Процент по группам   | Таблица    |
| Переменные           | Переменные |

### Структура таблицы "Процент по группам"

| Метка                 | Тип                                    | Описание                                                                                |
|:----------------------|:---------------------------------------|:----------------------------------------------------------------------------------------|
| Контрольная группа, % | ![](./img/realnumber.svg) Вещественный | Процент события по контрольной группе (группе, на которую не производилось воздействие) |
| Тестовая группа, %    | ![](./img/realnumber.svg) Вещественный | Процент события по тестовой группе (группе, на которую производилось воздействие)       |

### Переменные в порте "Переменные"

| № | Метка                | Тип                                    | Значение |
|:--|:---------------------|:---------------------------------------|:---------|
| 1 | Уровень значимости   | ![](./img/realnumber.svg) Вещественный | 0,05     |
| 2 | Тип теста            | ![](./img/integer.svg) Целый           | 0        |

1. **Уровень значимости** — это величина, используемая для оценки истинности некоторого результата или гипотезы. Популярными уровнями значимости являются: 
    
    * **0,05%** (по умолчанию);
    * **0,01%**; 
    * **0,001%**.

2. **Тип теста** — может принимать значения:

    * **0** (по умолчанию) — односторонний Т-тест;
    * **1** — двусторонний Т-тест;
    * **2** — теста Манна-Уитни (U-тест).

## Выходные порты

| Название             | Тип        |
|:---------------------|:-----------|
| Переменные           | Переменные |

### Переменные в порте "Переменные"

| №  | Метка                                 | Тип                                    | Описание                                                    |
|:---|:--------------------------------------|:---------------------------------------|:------------------------------------------------------------|
| 1  | Статистически значимая                | ![](./img/string.svg) Строковый        | Принимает значения **Да** или **Нет** (см. **Дополнительная литература**)                                         |
| 2  | Контрольная группа: кол-во наблюдений | ![](./img/integer.svg) Целый           | Кол-во наблюдений (записей) по контрольной группе в исходных данных       |
| 3  | Тестовая группа: кол-во наблюдений    | ![](./img/integer.svg) Целый           | Кол-во наблюдений по тестовой группе в исходных данных      |
| 4  | Уровень значимости                    | ![](./img/realnumber.svg) Вещественный | Выбранный уровень значимости                                |
| 5  | Значение критерия                     | ![](./img/realnumber.svg) Вещественный | Значение T-критерия или U-критерия, рассчитанное для групп  |
| 6  | Тип теста                             | ![](./img/string.svg) Строковый        | Выбранный тест                                              |
| 7  | Влияние воздействия, %                | ![](./img/realnumber.svg) Вещественный | (см. **Алгоритмы**)                                         |
| 8  | Контрольная группа: среднее           | ![](./img/realnumber.svg) Вещественный | Среднее значение по контрольной группе (Только для T-теста)|
| 9  | Тестовая группа: среднее              | ![](./img/realnumber.svg) Вещественный | Среднее значение по тестовой группе (Только для T-теста)   |
| 10 | Контрольная группа: дисперсия         | ![](./img/realnumber.svg) Вещественный | Дисперсия по контрольной группе (Только для T-теста)       |
| 11 | Тестовая группа: дисперсия            | ![](./img/realnumber.svg) Вещественный | Дисперсия по тестовой группе (Только для T-теста)          |

## Алгоритмы

1. **Влияние воздействия, %** — если в результате проверки поле *Статистически значимая* приняло значение **Да**, то расчет влияния воздействия для Т-теста будет происходить по формуле:

    ![](./img/impact.svg), где:

    * **TestAvg** — среднее значение по тестовой выборке;
    * **ControlAvg** — среднее значение по контрольной выборке.

## Дополнительная литература

1. [t-критерий Стьюдента - материал из Wikipedia (рус.)](https://ru.wikipedia.org/wiki/T-%D0%BA%D1%80%D0%B8%D1%82%D0%B5%D1%80%D0%B8%D0%B9_%D0%A1%D1%82%D1%8C%D1%8E%D0%B4%D0%B5%D0%BD%D1%82%D0%B0)
2. [U-критерий Манна — Уитни - материал из Wikipedia (рус.)](https://ru.wikipedia.org/wiki/U-%D0%BA%D1%80%D0%B8%D1%82%D0%B5%D1%80%D0%B8%D0%B9_%D0%9C%D0%B0%D0%BD%D0%BD%D0%B0_%E2%80%94_%D0%A3%D0%B8%D1%82%D0%BD%D0%B8)
